@@ -18,10 +18,24 @@ test_that("utils", {
   expect_true(is.fitdist(boron_lnorm))
   expect_true(is.fitdists(boron_dists))
   expect_true(is.fitdist(boron_dists[["lnorm"]]))
+  expect_true(is.fitdistcens(fluazinam_lnorm))
+  expect_true(is.fitdistscens(fluazinam_dists))
+  expect_true(is.fitdistcens(fluazinam_dists[[1]]))
+
   expect_identical(nobs(boron_lnorm), 28L)
   expect_identical(nobs(boron_dists), nobs(boron_lnorm))
+  expect_identical(nobs(fluazinam_lnorm), NA_integer_)
+  expect_identical(nobs(fluazinam_dists), NA_integer_)
+
   expect_identical(npars(boron_lnorm), 2L)
-  expect_identical(npars(boron_dists), c(lnorm = 2L, llog = 2L, gompertz = 2L, lgumbel = 2L, gamma = 2L, weibull = 2L))
-  expect_identical(comma_signif(1111), "1,000")
+  expect_identical(npars(boron_dists), c(
+    burrIII2 = 2L, gamma = 2L, lnorm = 2L
+  ))
+  expect_identical(npars(fluazinam_lnorm), 2L)
+  expect_identical(npars(fluazinam_dists), c(burrIII2 = 2L, gamma = 2L, lnorm = 2L))
+  expect_identical(
+    comma_signif(c(0.0191, 1, NA, 1111)),
+    c("0.02", "1", NA, "1,000")
+  )
   expect_equal(ssd_ecd(1:10), seq(0.05, 0.95, by = 0.1))
 })
